"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StreamUtils = void 0;
class StreamUtils {
    /**
     * @param size - file size
     * @param stream - readable stream
     * @param progress - optional progress handler
     * @returns promise that resolves buffer when accomplished
     */
    static streamToBuffer(size, stream, progress) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                let data = Buffer.from([]);
                if (progress != null) {
                    progress.start(size);
                }
                stream.on("data", (chunk) => {
                    data = Buffer.concat([data, chunk]);
                    if (progress != null) {
                        progress.worked(chunk.length);
                    }
                });
                stream.on("end", () => {
                    if (progress != null) {
                        progress.end();
                    }
                    resolve(data);
                });
                stream.on("error", (error) => {
                    if (progress != null) {
                        progress.end();
                    }
                    reject(error);
                });
                stream.resume();
            });
        });
    }
    /**
     * Pipes the readable stream to the writable stream.
     *
     * @param estimatedSize - estimated file size
     * @param stremPromise - promise that will resolve to a readable stream
     * @param writable - writable stream
     * @param progress - optional progress handler
     * @returns promise that resolves the downloaded bytes when accomplished
     */
    static streamToStream(size, stream, writable, progress) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                let downloadedBytes = 0;
                if (progress != null) {
                    progress.start(size);
                }
                stream.pipe(writable);
                stream.on("data", (chunk) => {
                    downloadedBytes += chunk.length;
                    if (progress != null) {
                        progress.worked(chunk.length);
                    }
                });
                stream.on("end", () => {
                    if (progress != null) {
                        progress.end();
                    }
                    resolve(downloadedBytes);
                });
                stream.on("error", (error) => {
                    if (progress != null) {
                        progress.end();
                    }
                    reject(error);
                });
            });
        });
    }
}
exports.StreamUtils = StreamUtils;
//# sourceMappingURL=StreamUtils.js.map