"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
const FTPProgressHandler_1 = require("../../../FTPProgressHandler");
const api_1 = require("../../../api");
class DownloadUssFileHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            const ussFile = api_1.UssUtils.normalizeUnixPath(params.arguments.ussFile);
            const file = params.arguments.file == null ?
                (0, path_1.basename)(ussFile) : // default the destination file name to the basename of the uss file e.g. /u/users/ibmuser/hello.txt -> hello.txt
                params.arguments.file;
            // Ensure to list directory if ussFile is under symbolic link of directory.
            const files = yield api_1.UssUtils.listFiles(params.connection, (0, path_1.dirname)(ussFile) + '/');
            const fileToDownload = files.find((f) => {
                return f.name === (0, path_1.basename)(ussFile);
            });
            if (fileToDownload === undefined) {
                throw new Error(`The file "${ussFile}" doesn't exist.`);
            }
            let progress;
            if (params.response && params.response.progress) {
                progress = new FTPProgressHandler_1.FTPProgressHandler(params.response.progress);
            }
            const options = {
                size: fileToDownload.size,
                localFile: file,
                response: params.response,
                transferType: params.arguments.binary ? api_1.TRANSFER_TYPE_BINARY : api_1.TRANSFER_TYPE_ASCII,
                progress,
            };
            yield api_1.UssUtils.downloadFile(params.connection, ussFile, options);
            const successMsg = params.response.console.log("Successfully downloaded USS file '%s' to local file '%s'", ussFile, file);
            this.log.info(successMsg);
            params.response.data.setMessage(successMsg);
        });
    }
}
exports.default = DownloadUssFileHandler;
//# sourceMappingURL=UssFile.Handler.js.map