"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const api_1 = require("../../../api");
const ImsBaseHandler_1 = require("../../ImsBaseHandler");
/**
 * Command handler for stopping IMS transactions
 * @export
 * @class TransactionHandler
 * @implements {ICommandHandler}
 */
class TransactionHandler extends ImsBaseHandler_1.ImsBaseHandler {
    processWithSession(params, session) {
        return __awaiter(this, void 0, void 0, function* () {
            const status = {
                statusMessage: "update transaction defined to IMS",
                percentComplete: 0,
                stageName: imperative_1.TaskStage.IN_PROGRESS
            };
            params.response.progress.startBar({ task: status });
            const response = yield api_1.updateTransaction(session, {
                name: params.arguments.name,
                aocmd: params.arguments.aocmd,
                class: params.arguments.class,
                cmtmode: params.arguments.cmtmode,
                conv: params.arguments.conv,
                cpri: params.arguments.cpri,
                dclwa: params.arguments.dclwa,
                dirroute: params.arguments.dirroute,
                editrtn: params.arguments.editrtn,
                edituc: params.arguments.edituc,
                emhbsz: params.arguments.emhbsz,
                exprtime: params.arguments.exprtime,
                fp: params.arguments.fp,
                inq: params.arguments.inq,
                lct: params.arguments.lct,
                lpri: params.arguments.lpri,
                lock: params.arguments.lock,
                maxrgn: params.arguments.maxrgn,
                msgtype: params.arguments.msgtype,
                msname: params.arguments.msname,
                npri: params.arguments.npri,
                option: params.arguments.option,
                parlim: params.arguments.parlim,
                pgm: params.arguments.pgm,
                plct: params.arguments.plct,
                plcttime: params.arguments.plcttime,
                recover: params.arguments.recover,
                remote: params.arguments.remote,
                resp: params.arguments.resp,
                route: params.arguments.route,
                scope: params.arguments.scope,
                segno: params.arguments.segno,
                segsz: params.arguments.segsz,
                serial: params.arguments.serial,
                setClass: params.arguments.setClass,
                sidl: params.arguments.sidl,
                sidr: params.arguments.sidr,
                spasz: params.arguments.spasz,
                spatrunc: params.arguments.spatrunc,
                transtat: params.arguments.transtat,
                wfi: params.arguments.wfi
            });
            this.checkReturnCode(response);
            params.response.console.log(imperative_1.TextUtils.prettyJson(response.data));
            imperative_1.Logger.getAppLogger().info("Messages from the update transaction API:\n" + JSON.stringify(response.messages, null, 2));
            return response;
        });
    }
}
exports.default = TransactionHandler;
//# sourceMappingURL=Transaction.handler.js.map