"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
const api_1 = require("../../../api");
/**
 * "zos-ftp view spool-by-id" command handler. Outputs a single spool DD contents.
 */
class SpoolFileByIdHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            this.log.debug("Getting spool file with id %s for job with ID %s", params.arguments.spoolfileid, params.arguments.jobid);
            // Get the content, set the JSON response object, and print
            const option = {
                jobName: "*",
                jobId: params.arguments.jobid,
                owner: "*",
                fileId: params.arguments.spoolfileid
            };
            /* Add await JobUtils.findJobByID(params.arguments.jobid, params.connection);
             * to avoid the list spool-files-by-jobid command and view spool-file-by-id making two separate FTP sessions.
             * And ensure the correct spool file can be retrieved.
             */
            const jobStatus = yield api_1.JobUtils.findJobByID(params.connection, params.arguments.jobid);
            option.jobName = jobStatus.jobname;
            const content = yield api_1.JobUtils.getSpoolFileContent(params.connection, option);
            params.response.data.setObj(content);
            const successMessage = this.log.info(`Spool file "${params.arguments.spoolfileid}" content obtained for job ID "${params.arguments.jobid})"`);
            params.response.data.setMessage(successMessage);
            params.response.console.log(Buffer.from(content));
        });
    }
}
exports.default = SpoolFileByIdHandler;
//# sourceMappingURL=SpoolFileById.Handler.js.map